@@ -113,6 +113,16 @@ int subgroupsMaxHoursDailyMaxHours[MAX_TOTAL_SUBGROUPS];
 double subgroupsMinHoursDailyPercentages[MAX_TOTAL_SUBGROUPS];
 int subgroupsMinHoursDailyMinHours[MAX_TOTAL_SUBGROUPS];
 
+// 2 activities consecutive
+//index represents the first activity, value in array represents the second activity
+QList<double> constr2ActivitiesConsecutivePercentages[MAX_ACTIVITIES];
+QList<int> constr2ActivitiesConsecutiveActivities[MAX_ACTIVITIES];
+
+//index represents the second activity, value in array represents the first activity
+QList<double> inverseConstr2ActivitiesConsecutivePercentages[MAX_ACTIVITIES];
+QList<int> inverseConstr2ActivitiesConsecutiveActivities[MAX_ACTIVITIES];
+// 2 activities consecutive
+
 ////////rooms
 double allowedRoomTimePercentages[MAX_ROOMS][MAX_HOURS_PER_WEEK]; //-1 for available
 
@@ -132,7 +142,7 @@ bool processTimeConstraints()
 	bool t=computeActivitiesConflictingPercentage();
 	if(!t)
 		return false;
-	sortActivities();
+	//sortActivities(); - done last time, because taking care of other constraints
 	//////////////////////////////
 	
 	/////2. min n days between activities
@@ -147,7 +157,9 @@ bool processTimeConstraints()
 	///////////////////////////////////////////////////////////////
 	
 	/////4. students no gaps and early
-	computeNHoursPerSubgroup();
+	t=computeNHoursPerSubgroup();
+	if(!t)
+		return false;
 	t=computeSubgroupsEarlyAndNoGapsPercentages();
 	if(!t)
 		return false;
@@ -161,7 +173,9 @@ bool processTimeConstraints()
 	
 	
 	/////6. TEACHERS MAX GAPS PER WEEK
-	computeNHoursPerTeacher();
+	t=computeNHoursPerTeacher();
+	if(!t)
+		return false;
 	t=computeTeachersMaxGapsPercentage();
 	if(!t)
 		return false;
@@ -189,7 +203,9 @@ bool processTimeConstraints()
 	t=computeSubgroupsMinHoursDaily();
 	if(!t)
 		return false;
-	
+		
+	computeConstr2ActivitiesConsecutive();
+		
 	/////////////rooms	
 	t=computeBasicSpace();
 	if(!t)
@@ -202,6 +218,8 @@ bool processTimeConstraints()
 		return false;
 	//////////////////
 	
+	sortActivities();
+	
 	bool ok=true;
 	
 	return ok;
@@ -420,6 +438,9 @@ bool computeSubgroupsMinHoursDaily()
 				int t=QMessageBox::warning(NULL, QObject::tr("FET warning"),
 				 QObject::tr("For subgroup %1 you have too little activities to respect the constraint"
 				 " of type min hours daily. Please modify your data accordingly and try again"
+				 ". A possible situation is that you have unneeded groups like 'year1 WHOLE YEAR' and subgroups with name like 'year1 WHOLE YEAR WHOLE GROUP'"
+				 ". You might need to remove such dummy groups and subgroups (they are generated if you start allocation"
+				 " with incomplete students data). FET cannot automatically remove such dummy groups and subgroups"
 				 ". For more details, join the mailing list or email the author")
 				 .arg(gt.rules.internalSubgroupsList[i]->name),
 				 QObject::tr("Skip rest of min hours problems"), QObject::tr("See next incompatibility min hours"), QString(),
@@ -613,7 +634,7 @@ void computeActivitiesSameStartingHour()
 }
 
 ////////////teachers' no gaps
-void computeNHoursPerTeacher()
+bool computeNHoursPerTeacher()
 {
 	for(int i=0; i<gt.rules.nInternalTeachers; i++)
 		nHoursPerTeacher[i]=0;
@@ -624,6 +645,53 @@ void computeNHoursPerTeacher()
 			nHoursPerTeacher[tc]+=act->duration;
 		}
 	}
+	
+	bool ok=true;
+	
+	for(int i=0; i<gt.rules.nInternalTeachers; i++)
+		if(nHoursPerTeacher[i]>gt.rules.nHoursPerWeek){
+			ok=false;
+
+			int t=QMessageBox::warning(NULL, QObject::tr("FET warning"),
+			 QObject::tr("Cannot optimize for teacher %1, because the number of hours for teacher is %2 "
+			  " and you have only %3 days x %4 hours in a week. Probably you need to increase with 1 the number"
+			  " of hours per day (probably you misunderstood FET hours notation)")
+			 .arg(gt.rules.internalTeachersList[i]->name)
+			 .arg(nHoursPerTeacher[i])
+			 .arg(gt.rules.nDaysPerWeek)
+			 .arg(gt.rules.nHoursPerDay),
+			 QObject::tr("Skip rest of teachers problems"), QObject::tr("See next teacher problem"), QString(),
+			 1, 0 );
+		 	
+			if(t==0)
+				return ok;
+		}
+	
+	for(int i=0; i<gt.rules.nInternalTeachers; i++){
+		int freeSlots=0;
+		for(int j=0; j<gt.rules.nDaysPerWeek; j++)
+			for(int k=0; k<gt.rules.nHoursPerDay; k++)
+				if(!teacherNotAvailableDayHour[i][j][k])
+					freeSlots++;
+		if(nHoursPerTeacher[i]>freeSlots){
+			ok=false;
+
+			int t=QMessageBox::warning(NULL, QObject::tr("FET warning"),
+			 QObject::tr("Cannot optimize for teacher %1, because the number of hours for teacher is %2 "
+			  " and you have only %3 free slots from constraints teacher not available. Maybe you inputted wrong constraints teacher"
+			  " not available or the number of hours per day is less with 1, because of a misunderstanding")
+			 .arg(gt.rules.internalTeachersList[i]->name)
+			 .arg(nHoursPerTeacher[i])
+			 .arg(freeSlots),
+			 QObject::tr("Skip rest of teach. not avail. problems"), QObject::tr("See next teach. not avail. problem"), QString(),
+			 1, 0 );
+		 	
+			if(t==0)
+				return ok;
+		}
+	}
+	
+	return ok;
 }
 
 bool computeTeachersMaxGapsPercentage()
@@ -634,6 +702,43 @@ bool computeTeachersMaxGapsPercentage()
 	}
 	
 	bool ok=true;
+
+	for(int i=0; i<gt.rules.nInternalTimeConstraints; i++){
+		if(gt.rules.internalTimeConstraintsList[i]->type==CONSTRAINT_TEACHERS_MAX_GAPS_PER_WEEK){
+			ConstraintTeachersMaxGapsPerWeek* tg=(ConstraintTeachersMaxGapsPerWeek*)gt.rules.internalTimeConstraintsList[i];
+
+			if(tg->weightPercentage!=100){
+				ok=false;
+
+				int t=QMessageBox::warning(NULL, QObject::tr("FET warning"),
+				 QObject::tr("Cannot optimize, because you have constraint teachers max gaps with"
+				 " weight (percentage) below 100. Please make weight 100% and try again"),
+				 QObject::tr("Skip rest of max gaps problems"), QObject::tr("See next incompatibility max gaps"), QString(),
+				 1, 0 );
+			 	
+				if(t==0)
+					return false;
+			}
+		}
+
+		if(gt.rules.internalTimeConstraintsList[i]->type==CONSTRAINT_TEACHER_MAX_GAPS_PER_WEEK){
+			ConstraintTeacherMaxGapsPerWeek* tg=(ConstraintTeacherMaxGapsPerWeek*)gt.rules.internalTimeConstraintsList[i];
+
+			if(tg->weightPercentage!=100){
+				ok=false;
+
+				int t=QMessageBox::warning(NULL, QObject::tr("FET warning"),
+				 QObject::tr("Cannot optimize, because you have constraint teacher max gaps with"
+				 " weight (percentage) below 100 for teacher %1. Please make weight 100% and try again")
+				 .arg(tg->teacherName),
+				 QObject::tr("Skip rest of max gaps problems"), QObject::tr("See next incompatibility max gaps"), QString(),
+				 1, 0 );
+			 	
+				if(t==0)
+					return false;
+			}
+		}
+	}
 	
 	for(int i=0; i<gt.rules.nInternalTimeConstraints; i++){
 		if(gt.rules.internalTimeConstraintsList[i]->type==CONSTRAINT_TEACHERS_MAX_GAPS_PER_WEEK){
@@ -669,7 +774,7 @@ bool computeTeachersMaxGapsPercentage()
 		}
 		if(gt.rules.internalTimeConstraintsList[i]->type==CONSTRAINT_TEACHER_MAX_GAPS_PER_WEEK){
 			ConstraintTeacherMaxGapsPerWeek* tg=(ConstraintTeacherMaxGapsPerWeek*)gt.rules.internalTimeConstraintsList[i];
-			
+		
 			int j=tg->teacherIndex;
 			if(teachersMaxGapsMaxGaps[j]==-1 
 			 ||	teachersMaxGapsMaxGaps[j]>=0 && teachersMaxGapsMaxGaps[j]>=tg->maxGaps && teachersMaxGapsPercentage[j]<=tg->weightPercentage){
@@ -705,7 +810,7 @@ bool computeTeachersMaxGapsPercentage()
 
 
 ///////students' no gaps and early (part 1)
-void computeNHoursPerSubgroup()
+bool computeNHoursPerSubgroup()
 {
 	for(int i=0; i<gt.rules.nInternalSubgroups; i++)
 		nHoursPerSubgroup[i]=0;
@@ -716,6 +821,52 @@ void computeNHoursPerSubgroup()
 			nHoursPerSubgroup[isg]+=act->duration;
 		}
 	}
+	
+	bool ok=true;
+	for(int i=0; i<gt.rules.nInternalSubgroups; i++)
+		if(nHoursPerSubgroup[i]>gt.rules.nHoursPerWeek){
+			ok=false;
+
+			int t=QMessageBox::warning(NULL, QObject::tr("FET warning"),
+			 QObject::tr("Cannot optimize for subgroup %1, because the number of hours for subgroup is %2 "
+			  " and you have only %3 days x %4 hours in a week. Probably you need to increase with 1 the number"
+			  " of hours per day (probably you misunderstood FET hours notation)")
+			 .arg(gt.rules.internalSubgroupsList[i]->name)
+			 .arg(nHoursPerSubgroup[i])
+			 .arg(gt.rules.nDaysPerWeek)
+			 .arg(gt.rules.nHoursPerDay),
+			 QObject::tr("Skip rest of students problems"), QObject::tr("See next students problem"), QString(),
+			 1, 0 );
+		 	
+			if(t==0)
+				return ok;
+		}
+		
+	for(int i=0; i<gt.rules.nInternalSubgroups; i++){
+		int freeSlots=0;
+		for(int j=0; j<gt.rules.nDaysPerWeek; j++)
+			for(int k=0; k<gt.rules.nHoursPerDay; k++)
+				if(!subgroupNotAvailableDayHour[i][j][k])
+					freeSlots++;
+		if(nHoursPerSubgroup[i]>freeSlots){
+			ok=false;
+
+			int t=QMessageBox::warning(NULL, QObject::tr("FET warning"),
+			 QObject::tr("Cannot optimize for subgroup %1, because the number of hours for subgroup is %2 "
+			  " and you have only %3 free slots from constraints students set not available. Maybe you inputted wrong constraints students set"
+			  " not available or the number of hours per day is less with 1, because of a misunderstanding")
+			 .arg(gt.rules.internalSubgroupsList[i]->name)
+			 .arg(nHoursPerSubgroup[i])
+			 .arg(freeSlots),
+			 QObject::tr("Skip rest of stud. not avail. problems"), QObject::tr("See next stud. not avail. problem"), QString(),
+			 1, 0 );
+		 	
+			if(t==0)
+				return ok;
+		}
+	}
+		
+	return ok;
 }
 
 
@@ -1290,6 +1441,45 @@ bool computeActivitiesConflictingPercentage()
 		
 	return true;
 }
+
+void computeConstr2ActivitiesConsecutive()
+{
+	for(int i=0; i<gt.rules.nInternalActivities; i++){
+		constr2ActivitiesConsecutivePercentages[i].clear();
+		constr2ActivitiesConsecutiveActivities[i].clear();
+
+		inverseConstr2ActivitiesConsecutivePercentages[i].clear();
+		inverseConstr2ActivitiesConsecutiveActivities[i].clear();
+	}
+
+	for(int i=0; i<gt.rules.nInternalTimeConstraints; i++)
+		if(gt.rules.internalTimeConstraintsList[i]->type==CONSTRAINT_2_ACTIVITIES_CONSECUTIVE){
+			Constraint2ActivitiesConsecutive* c2=(Constraint2ActivitiesConsecutive*)gt.rules.internalTimeConstraintsList[i];
+			
+			int fai=c2->firstActivityIndex;
+			int sai=c2->secondActivityIndex;
+			
+			//direct
+			int j=constr2ActivitiesConsecutiveActivities[fai].indexOf(sai); 
+			if(j==-1){
+				constr2ActivitiesConsecutiveActivities[fai].append(sai);
+				constr2ActivitiesConsecutivePercentages[fai].append(c2->weightPercentage);
+			}
+			else if(j>=0 && constr2ActivitiesConsecutivePercentages[fai].at(j)<c2->weightPercentage){
+				constr2ActivitiesConsecutivePercentages[fai][j]=c2->weightPercentage;
+			}
+
+			//inverse
+			j=inverseConstr2ActivitiesConsecutiveActivities[sai].indexOf(fai); 
+			if(j==-1){
+				inverseConstr2ActivitiesConsecutiveActivities[sai].append(fai);
+				inverseConstr2ActivitiesConsecutivePercentages[sai].append(c2->weightPercentage);
+			}
+			else if(j>=0 && inverseConstr2ActivitiesConsecutivePercentages[sai].at(j)<c2->weightPercentage){
+				inverseConstr2ActivitiesConsecutivePercentages[sai][j]=c2->weightPercentage;
+			}
+		}
+}
 	
 /*void Rules::computeActivitiesSimilar()
 {
@@ -1555,6 +1745,55 @@ bool computeActivitiesRoomsPreferences()
 				}
 			}
 		}
+		else if(gt.rules.internalSpaceConstraintsList[i]->type==CONSTRAINT_SUBJECT_SUBJECT_TAG_PREFERRED_ROOM){
+			ConstraintSubjectSubjectTagPreferredRoom* spr=(ConstraintSubjectSubjectTagPreferredRoom*)gt.rules.internalSpaceConstraintsList[i];
+			
+			for(int j=0; j<spr->_nActivities; j++){
+				int a=spr->_activities[j];
+				
+				if(unspecifiedRoom[a]){
+					unspecifiedRoom[a]=false;
+					activitiesPreferredRoomsPercentage[a]=spr->weightPercentage;
+					assert(activitiesPreferredRoomsPreferredRooms[a].count()==0);
+					activitiesPreferredRoomsPreferredRooms[a].append(spr->_room);
+				}
+				else{
+					int t=activitiesPreferredRoomsPreferredRooms[a].indexOf(spr->_room);
+					activitiesPreferredRoomsPreferredRooms[a].clear();
+					activitiesPreferredRoomsPercentage[a]=max(activitiesPreferredRoomsPercentage[a], spr->weightPercentage);
+					if(t!=-1){
+						activitiesPreferredRoomsPreferredRooms[a].append(spr->_room);
+					}
+				}
+			}
+		}
+		else if(gt.rules.internalSpaceConstraintsList[i]->type==CONSTRAINT_SUBJECT_SUBJECT_TAG_PREFERRED_ROOMS){
+			ConstraintSubjectSubjectTagPreferredRooms* spr=(ConstraintSubjectSubjectTagPreferredRooms*)gt.rules.internalSpaceConstraintsList[i];
+			
+			for(int j=0; j<spr->_nActivities; j++){
+				int a=spr->_activities[j];
+				
+				if(unspecifiedRoom[a]){
+					unspecifiedRoom[a]=false;
+					activitiesPreferredRoomsPercentage[a]=spr->weightPercentage;
+					assert(activitiesPreferredRoomsPreferredRooms[a].count()==0);
+					for(int k=0; k<spr->_n_preferred_rooms; k++){
+						int rm=spr->_rooms[k];
+						activitiesPreferredRoomsPreferredRooms[a].append(rm);
+					}
+				}
+				else{
+					QList<int> shared;
+					for(int k=0; k<spr->_n_preferred_rooms; k++){
+						int rm=spr->_rooms[k];
+						if(activitiesPreferredRoomsPreferredRooms[a].indexOf(rm)!=-1)
+							shared.append(rm);
+					}
+					activitiesPreferredRoomsPercentage[a]=max(activitiesPreferredRoomsPercentage[a], spr->weightPercentage);
+					activitiesPreferredRoomsPreferredRooms[a]=shared;
+				}
+			}
+		}
 		else if(gt.rules.internalSpaceConstraintsList[i]->type==CONSTRAINT_ACTIVITY_PREFERRED_ROOM){
 			ConstraintActivityPreferredRoom* apr=(ConstraintActivityPreferredRoom*)gt.rules.internalSpaceConstraintsList[i];
 			
@@ -1610,7 +1849,7 @@ bool computeActivitiesRoomsPreferences()
 				
 				int t=QMessageBox::warning(NULL, QObject::tr("FET warning"),
 				 QObject::tr("Cannot generate timetable, because for activity with id==%1 "
-				 "you have no allowed room (from constraints subject preferred room(s) and activity preferred room(s) )")
+				 "you have no allowed room (from constraints subject (subject tag) preferred room(s) and activity preferred room(s) )")
 				 .arg(gt.rules.internalActivitiesList[i].id),
 				 QObject::tr("Skip rest of activities without rooms"), QObject::tr("See next problem"), QString(),
 				 1, 0 );
@@ -1648,18 +1887,160 @@ bool computeActivitiesRoomsPreferences()
 	return ok;
 }
 
+#if 1
+void sortActivities()
+{
+	const double THRESHOLD=80.0;
+	
+	static int nIncompatible[MAX_ACTIVITIES];
+	
+	
+	
+	//rooms init
+	int nRoomsIncompat[MAX_ROOMS];
+	for(int j=0; j<gt.rules.nInternalRooms; j++){
+		nRoomsIncompat[j]=0;
+		for(int k=0; k<gt.rules.nHoursPerWeek; k++)
+			if(allowedRoomTimePercentages[j][k]>=THRESHOLD)
+				nRoomsIncompat[j]++;
+	}
+	int nHoursForRoom[MAX_ROOMS];	
+
+	for(int j=0; j<gt.rules.nInternalRooms; j++)
+		nHoursForRoom[j]=0;
+
+	for(int j=0; j<gt.rules.nInternalActivities; j++)
+		if(activitiesPreferredRoomsPercentage[j]>=THRESHOLD){
+			assert(!unspecifiedRoom[j]);
+			foreach(int rm, activitiesPreferredRoomsPreferredRooms[j])
+				nHoursForRoom[rm]+=gt.rules.internalActivitiesList[j].duration;
+		}
+
+	
+
+	for(int i=0; i<gt.rules.nInternalActivities; i++){
+		nIncompatible[i]=0;
+		
+		//basic
+		for(int j=0; j<gt.rules.nInternalActivities; j++)
+			if(i!=j && activitiesConflictingPercentage[i][j]>=THRESHOLD){
+				assert(activitiesConflictingPercentage[i][j]==100.0);
+				nIncompatible[i]+=gt.rules.internalActivitiesList[j].duration;
+			}
+				
+		//not available, break, preferred time(s)
+		for(int j=0; j<gt.rules.nHoursPerWeek; j++)
+			if(allowedTimesPercentages[i][j]>=THRESHOLD)
+				nIncompatible[i]++;
+		
+		//min n days
+		/*for(int j=0; j<minNDaysListOfActivities[i].count(); j++){
+			int md=minNDaysListOfMinDays[i].at(j);
+			double wp=minNDaysListOfWeightPercentages[i].at(j);
+			if(wp>=THRESHOLD)
+				nImpossibleSlots+=gt.rules.nHoursPerDay*md;
+		}*/
+		
+
+		//teachers max days per week
+		foreach(int t, teachersWithMaxDaysPerWeekForActivities[i]){
+			if(teachersMaxDaysPerWeekWeightPercentages[t]>=THRESHOLD)
+				assert(gt.rules.nDaysPerWeek-teachersMaxDaysPerWeekMaxDays[t] >=0 );
+				nIncompatible[i]+=(gt.rules.nDaysPerWeek-teachersMaxDaysPerWeekMaxDays[t])*gt.rules.nHoursPerDay;
+		}
+
+		
+		//rooms
+		if(activitiesPreferredRoomsPercentage[i]>=THRESHOLD){
+			int cnt=0;
+			assert(!unspecifiedRoom[i]);
+			foreach(int rm, activitiesPreferredRoomsPreferredRooms[i])
+				cnt+=nRoomsIncompat[rm]+nHoursForRoom[rm]-1; //-1 because we considered also current activity
+				
+			nIncompatible[i] += cnt / activitiesPreferredRoomsPreferredRooms[i].count(); //average for all the rooms
+		}
+				
+		
+
+		nIncompatible[i]*=gt.rules.internalActivitiesList[i].duration;
+	}
+
+	//same starting time - not computing, the algo takes care even without correct sorting
+	//it is difficult to sort about same starting time
+	/*
+	careful - must pass more than one time
+	for(int i=0; i<gt.rules.nInternalActivities; i++){
+		for(int j=0; j<activitiesSameStartingTimeActivities[i].count(); j++){
+			int a2=activitiesSameStartingTimeActivities[i].at(j);
+			int wp=activitiesSameStartingTimePercentages[i].at(j);
+			if(wp>=THRESHOLD)
+				nIncompatible[i]=max(nIncompatible[i], nIncompatible[a2]);
+		}
+	}*/
+	
+	//Sort activities in in-creasing order of number of the other activities with which
+	//this activity does not conflict
+	//Selection sort, based on a permutation
+	for(int i=0; i<gt.rules.nInternalActivities; i++)
+		permutation[i]=i;
+		
+	for(int i=0; i<gt.rules.nInternalActivities; i++){
+		for(int j=i+1; j<gt.rules.nInternalActivities; j++){
+			if(nIncompatible[permutation[i]]<nIncompatible[permutation[j]]){
+				int t=permutation[i];
+				permutation[i]=permutation[j];
+				permutation[j]=t;
+			}
+		}
+	}
+	
+	cout<<"The order of activities (id-s):"<<endl;
+	for(int i=0; i<gt.rules.nInternalActivities; i++){
+		cout<<"No: "<<i+1<<", nIncompatible[permutation[i]]=="<<nIncompatible[permutation[i]]<<", ";
+	
+		Activity* act=&gt.rules.internalActivitiesList[permutation[i]];
+		cout<<"id=="<<act->id;
+		cout<<", teachers: ";
+		foreach(QString s, act->teachersNames)
+			cout<<qPrintable(s)<<" ";
+		cout<<", subj=="<<qPrintable(act->subjectName);
+		cout<<", students: ";
+		foreach(QString s, act->studentsNames)
+			cout<<qPrintable(s)<<" ";
+		cout<<endl;
+	}
+	cout<<"End - the order of activities (id-s):"<<endl;
+	//assert(0);
+
+	//RANDOM ORDER
+	/*for(int i=0; i<gt.rules.nInternalActivities; i++)
+		permutation[i]=i;
+	for(int i=0; i<gt.rules.nInternalActivities*gt.rules.nInternalActivities/2; i++){
+		int j=randomKnuth()%gt.rules.nInternalActivities;
+		int k=randomKnuth()%gt.rules.nInternalActivities;
+		int tmp;
+		tmp=permutation[j];
+		permutation[j]=permutation[k];
+		permutation[k]=tmp;
+	}*/
+}
+#endif
+
+#if 0
 void sortActivities()
 {
 	//computeMinNDays();
 	
-	static int nCompatible[MAX_ACTIVITIES];
+	static int nIncompatible[MAX_ACTIVITIES];
 
 	for(int i=0; i<gt.rules.nInternalActivities; i++){
-		nCompatible[i]=0;
+		nIncompatible[i]=0;
 		
 		for(int j=0; j<gt.rules.nInternalActivities; j++)
-			if(i!=j && activitiesConflictingPercentage[i][j]==-1)
-				nCompatible[i]++;
+			if(i!=j && activitiesConflictingPercentage[i][j]>=0)
+				nIncompatible[i]+=gt.rules.internalActivitiesList[j].duration;
+
+		nIncompatible[i]*=gt.rules.internalActivitiesList[i].duration;
 				
 	/*	nCompatible[i] -= 5
 		 *minNDaysListOfActivities[i].count()
@@ -1676,7 +2057,7 @@ void sortActivities()
 		
 	for(int i=0; i<gt.rules.nInternalActivities; i++){
 		for(int j=i+1; j<gt.rules.nInternalActivities; j++){
-			if(nCompatible[permutation[i]]>nCompatible[permutation[j]]){
+			if(nIncompatible[permutation[i]]<nIncompatible[permutation[j]]){
 				int t=permutation[i];
 				permutation[i]=permutation[j];
 				permutation[j]=t;
@@ -1701,3 +2082,4 @@ void sortActivities()
 		permutation[k]=tmp;
 	}*/
 }
+#endif
