@@ -20,6 +20,7 @@ using namespace std;
 #include "fetmainform.h"
 
 #include "timetablegenerateform.h"
+#include "timetablegeneratemultipleform.h"
 
 #include "timetableviewstudentsform.h"
 #include "timetableviewteachersform.h"
@@ -49,6 +50,7 @@ using namespace std;
 
 #include "fet.h"
 
+#include "constraint2activitiesconsecutiveform.h"
 #include "constraintactivitiespreferredtimesform.h"
 #include "constraintactivitiessamestartingtimeform.h"
 #include "constraintactivitiessamestartinghourform.h"
@@ -79,6 +81,8 @@ using namespace std;
 #include "constraintactivitypreferredroomsform.h"
 #include "constraintsubjectpreferredroomform.h"
 #include "constraintsubjectpreferredroomsform.h"
+#include "constraintsubjectsubjecttagpreferredroomform.h"
+#include "constraintsubjectsubjecttagpreferredroomsform.h"
 
 #include <qmessagebox.h>
 #include <q3filedialog.h>
@@ -94,6 +98,8 @@ using namespace std;
 
 bool simulation_running; //true if the user started an allocation of the timetable
 
+bool simulation_running_multi;
+
 bool students_schedule_ready;
 bool teachers_schedule_ready;
 bool rooms_schedule_ready;
@@ -243,7 +249,7 @@ void FetMainForm::closeEvent(QCloseEvent* event)
 
 	switch(QMessageBox::information( this, QObject::tr("FET - exiting"),
 	 QObject::tr("File not saved - do you want to save it?"),
-	 QObject::tr("&Yes"), QObject::tr("&No"), QObject::tr("&Cancel"), 0 , 2 )){	 
+	 QObject::tr("&Yes"), QObject::tr("&No"), QObject::tr("&Cancel"), 0 , 2 )){
 	 	case 0: 
 			this->on_fileSaveAction_activated();
 			event->accept();
@@ -256,7 +262,7 @@ void FetMainForm::closeEvent(QCloseEvent* event)
 			break;
 	}
 
-	INPUT_FILENAME_XML = "";
+	//INPUT_FILENAME_XML = "";
 }
 
 FetMainForm::~FetMainForm()
@@ -569,6 +575,18 @@ void FetMainForm::on_dataAllSpaceConstraintsAction_activated()
 	form->exec();
 }
 
+void FetMainForm::on_dataTimeConstraints2ActivitiesConsecutiveAction_activated()
+{
+	if(simulation_running){
+		QMessageBox::information(this, QObject::tr("FET information"),
+			QObject::tr("Allocation in course.\nPlease stop simulation before this."));
+		return;
+	}
+
+	Constraint2ActivitiesConsecutiveForm* form=new Constraint2ActivitiesConsecutiveForm();
+	form->exec();
+}
+
 void FetMainForm::on_dataTimeConstraintsActivitiesPreferredTimesAction_activated()
 {
 	if(simulation_running){
@@ -701,6 +719,30 @@ void FetMainForm::on_dataSpaceConstraintsSubjectPreferredRoomsAction_activated()
 	form->exec();
 }
 
+void FetMainForm::on_dataSpaceConstraintsSubjectSubjectTagPreferredRoomAction_activated()
+{
+	if(simulation_running){
+		QMessageBox::information(this, QObject::tr("FET information"),
+			QObject::tr("Allocation in course.\nPlease stop simulation before this."));
+		return;
+	}
+
+	ConstraintSubjectSubjectTagPreferredRoomForm* form=new ConstraintSubjectSubjectTagPreferredRoomForm();
+	form->exec();
+}
+
+void FetMainForm::on_dataSpaceConstraintsSubjectSubjectTagPreferredRoomsAction_activated()
+{
+	if(simulation_running){
+		QMessageBox::information(this, QObject::tr("FET information"),
+			QObject::tr("Allocation in course.\nPlease stop simulation before this."));
+		return;
+	}
+
+	ConstraintSubjectSubjectTagPreferredRoomsForm* form=new ConstraintSubjectSubjectTagPreferredRoomsForm();
+	form->exec();
+}
+
 void FetMainForm::on_dataTimeConstraintsStudentsSetNotAvailableAction_activated()
 {
 	if(simulation_running){
@@ -968,7 +1010,37 @@ void FetMainForm::on_timetableGenerateAction_activated()
 		return;
 	}
 	TimetableGenerateForm *form=new TimetableGenerateForm();
-	form->show();
+	form->exec();
+}
+
+void FetMainForm::on_timetableGenerateMultipleAction_activated()
+{
+	if(simulation_running){
+		QMessageBox::information(this, QObject::tr("FET information"),
+			QObject::tr("Allocation in course.\nPlease stop simulation before this."));
+		return;
+	}
+
+	if(INPUT_FILENAME_XML==""){
+		QMessageBox::information(this, QObject::tr("FET information"),
+			QObject::tr("Current file (data) has no name. Please save file under a certain name before proceeding"));
+		return;
+	}
+
+	int count=0;
+	for(int i=0; i<gt.rules.activitiesList.size(); i++){
+		Activity* act=gt.rules.activitiesList[i];
+		if(act->active){
+			//cout<<"here: i=="<<i<<endl;
+			count++;
+		}
+	}
+	if(count<2){
+		QMessageBox::information(this, QObject::tr("FET information"), QObject::tr("Please input at least two active activities before generating multiple"));
+		return;
+	}
+	TimetableGenerateMultipleForm *form=new TimetableGenerateMultipleForm();
+	form->exec();
 }
 
 void FetMainForm::on_timetableViewStudentsAction_activated()
