@@ -64,11 +64,14 @@ public slots:
 	void on_dataSpaceConstraintsActivityPreferredRoomsAction_activated();
 	void on_dataSpaceConstraintsSubjectPreferredRoomAction_activated();
 	void on_dataSpaceConstraintsSubjectPreferredRoomsAction_activated();
+	void on_dataSpaceConstraintsSubjectSubjectTagPreferredRoomAction_activated();
+	void on_dataSpaceConstraintsSubjectSubjectTagPreferredRoomsAction_activated();
 	
 
 	void on_dataTimeConstraintsBasicCompulsoryTimeAction_activated();
 	void on_dataTimeConstraintsBreakAction_activated();
 
+	void on_dataTimeConstraints2ActivitiesConsecutiveAction_activated();
 	void on_dataTimeConstraintsActivityPreferredTimeAction_activated();
 	void on_dataTimeConstraintsActivityPreferredTimesAction_activated();
 	void on_dataTimeConstraintsActivitiesPreferredTimesAction_activated();
@@ -104,6 +107,7 @@ public slots:
 	void on_timetableViewTeachersAction_activated();
 	void on_timetableShowConflictsAction_activated();
 	void on_timetableViewRoomsAction_activated();
+	void on_timetableGenerateMultipleAction_activated();
 	
 	void on_languageEnglishAction_activated();
 	void on_languageFrenchAction_activated();
